==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/gl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Caducou o contrasinal, use o método de contrasinal esquecido para restabelecelo",
    "Password must not have been used recently before." : "O contrasinal non debe ter sido empregado recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "O contrasinal está entre o 1.000.000 máis común. Escolla un diferente.",
    "Password is present in compromised password list. Please choose a different password." : "O contrasinal atopase nunha lista de contrasinais comprometidos. Escolla un contrasinal diferente.",
    "Password needs to be at least %s characters long" : "O contrasinal precisa ser polo menos de %s caracteres de lonxitude",
    "Password needs to contain at least one numeric character." : "O contrasinal precisa conter polo menos un caracter numérico.",
    "Password needs to contain at least one special character." : "O contrasinal precisa conter polo menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "O contrasinal precisa conter polo menos un caracter en minúsculas e un en maiúsculas.",
    "Password policy" : "Directiva de contrasinais",
    "Allows admins to configure a password policy" : "Permítelle aos administradores  configurar unha política de contrasinais",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permítelle aos administradores definir certas precondicións para os contrasinais, p. ex., obrigar a unha lonxitude mínima",
    "Minimal length" : "Lonxitude mínima",
    "User password history" : "Historial de contrasinais do usuario",
    "days until user password expires" : "días ata que caduque o contrasinal do usuario",
    "login attempts before the user account is blocked. (0 for no limit)" : "intentos de acceso antes de que se bloquee a conta do usuario. (0 para sen límite)",
    "Forbid common passwords" : "Prohibir contrasinais comúns",
    "Enforce upper and lower case characters" : "Forzar caracteres en maiúsculas e minúsculas",
    "Enforce numeric characters" : "Forzar caracteres numéricos",
    "Enforce special characters" : "Forzar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar o contrasinal contra a lista de contrasinais comprometidos de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un «hash» dos contrasinais e envía os 5 primeiros caracteres deste «hash» á API de haveibeenpwned.com para recuperar unha lista de todos os «hash» que comezan desa forma. Após comprobase na instancia de Nextcloud se o «hash» do contrasinal está no conxunto de resultados."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/gl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Caducou o contrasinal, use o método de contrasinal esquecido para restabelecelo",
    "Password must not have been used recently before." : "O contrasinal non debe ter sido empregado recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "O contrasinal está entre o 1.000.000 máis común. Escolla un diferente.",
    "Password is present in compromised password list. Please choose a different password." : "O contrasinal atopase nunha lista de contrasinais comprometidos. Escolla un contrasinal diferente.",
    "Password needs to be at least %s characters long" : "O contrasinal precisa ser polo menos de %s caracteres de lonxitude",
    "Password needs to contain at least one numeric character." : "O contrasinal precisa conter polo menos un caracter numérico.",
    "Password needs to contain at least one special character." : "O contrasinal precisa conter polo menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "O contrasinal precisa conter polo menos un caracter en minúsculas e un en maiúsculas.",
    "Password policy" : "Directiva de contrasinais",
    "Allows admins to configure a password policy" : "Permítelle aos administradores  configurar unha directiva de contrasinais",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permítelle aos administradores definir certas precondicións para os contrasinais, p. ex., obrigar a unha lonxitude mínima",
    "Minimal length" : "Lonxitude mínima",
    "User password history" : "Historial de contrasinais do usuario",
    "days until user password expires" : "días ata que caduque o contrasinal do usuario",
    "login attempts before the user account is blocked. (0 for no limit)" : "intentos de acceso antes de que se bloquee a conta do usuario. (0 para sen límite)",
    "Forbid common passwords" : "Prohibir contrasinais comúns",
    "Enforce upper and lower case characters" : "Forzar caracteres en maiúsculas e minúsculas",
    "Enforce numeric characters" : "Forzar caracteres numéricos",
    "Enforce special characters" : "Forzar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar o contrasinal contra a lista de contrasinais comprometidos de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un «hash» dos contrasinais e envía os 5 primeiros caracteres deste «hash» á API de haveibeenpwned.com para recuperar unha lista de todos os «hash» que comezan desa forma. Após comprobase na instancia de Nextcloud se o «hash» do contrasinal está no conxunto de resultados."
},
"nplurals=2; plural=(n != 1);");
